@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2020 Olivier Girondel
+ *  Copyright 1994-2021 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -219,6 +219,25 @@ open_video(Context_t *ctx, const char *file)
 }
 
 
+static void
+free_allocated()
+{
+  if (NULL != codec_ctx) {
+    avcodec_close(codec_ctx);
+  }
+  if (NULL != fmt_ctx) {
+    avformat_close_input(&fmt_ctx);
+  }
+  if (NULL != frame) {
+    av_frame_free(&frame);
+  }
+  if (NULL != packet) {
+    av_packet_free(&packet);
+  }
+  free_swscale_data();
+}
+
+
 static void
 close_video()
 {
@@ -226,19 +245,7 @@ close_video()
     thread_exit = 1;
     xpthread_join(video_thread, NULL);
     thread_running = 0;
-    if (NULL != codec_ctx) {
-      avcodec_close(codec_ctx);
-    }
-    if (NULL != fmt_ctx) {
-      avformat_close_input(&fmt_ctx);
-    }
-    if (NULL != frame) {
-      av_frame_free(&frame);
-    }
-    if (NULL != packet) {
-      av_packet_free(&packet);
-    }
-    free_swscale_data();
+    free_allocated();
   }
 }
 
@@ -303,6 +310,7 @@ void
 destroy(Context_t *ctx)
 {
   close_video();
+  free_allocated();
   json_decref(playlist);
   Shuffler_delete(shuffler);
   Buffer8_delete(video_buffer);
