@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2020 Olivier Girondel
+ *  Copyright 1994-2021 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -26,26 +26,6 @@
 #include "colormaps.h"
 #include "paths.h"
 
-
-/* Auto-change timers and modes */
-static char *delay_names[MAX_TIMERS] = {
-  "colormaps",
-  "images",
-  "sequences"
-#ifdef WITH_WEBCAM
-  , "webcams"
-#endif
-};
-
-static int delays[MAX_TIMERS][2] = {
-  { DELAY_MIN, DELAY_MAX },  // colormaps
-  { DELAY_MIN, DELAY_MAX },  // images
-  { DELAY_MIN, DELAY_MAX }   // sequences
-#ifdef WITH_WEBCAM
-  , { DELAY_MIN, DELAY_MAX } // webcams
-#endif
-};
-
 uint8_t start_with_first_sequence = 0;
 
 static pthread_t images_thread;
@@ -141,37 +121,8 @@ biniou_new(const char *datadir, const char *pluginsdir,
     Colormaps_new(NULL);
   }
 
-  /* Create images fader and timer */
-  if (NULL != images) {
-    VERBOSE(printf("[+] Creating images fader (%i images)\n", images->size));
-    context->imgf = ImageFader_new(images->size);
-
-    VERBOSE(printf("[+] Creating images timer (%d..%d)\n", delays[BD_IMAGES][0], delays[BD_IMAGES][1]));
-    context->a_images = Alarm_new(delays[BD_IMAGES][0], delays[BD_IMAGES][1]);
-  }
-
-  /* Create colormaps fader and timer */
-  if (NULL != colormaps) {
-    VERBOSE(printf("[+] Creating colormaps fader (%i colormaps)\n", colormaps->size));
-    context->cf = CmapFader_new(colormaps->size);
-
-    VERBOSE(printf("[+] Creating colormaps timer (%d..%d)\n", delays[BD_COLORMAPS][0], delays[BD_COLORMAPS][1]));
-    context->a_cmaps = Alarm_new(delays[BD_COLORMAPS][0], delays[BD_COLORMAPS][1]);
-  }
-
-  /* Create sequences timer */
-  VERBOSE(printf("[+] Creating sequences timer (%d..%d)\n", delays[BD_SEQUENCES][0], delays[BD_SEQUENCES][1]));
-  context->a_random = Alarm_new(delays[BD_SEQUENCES][0], delays[BD_SEQUENCES][1]);
-  context->random_mode = BR_NONE;
-
-#ifdef WITH_WEBCAM
-  /* Create webcams timer */
-  if (webcams > 1) {
-    VERBOSE(printf("[+] Creating webcams timer (%d..%d)\n", delays[BD_WEBCAMS][0], delays[BD_WEBCAMS][1]));
-    context->a_webcams = Alarm_new(delays[BD_WEBCAMS][0], delays[BD_WEBCAMS][1]);
-    Alarm_init(context->a_webcams);
-  }
-#endif
+  // Create timers
+  Context_create_timers(context);
 
   /* Schemes */
   if (options & B_INIT_SCHEMES) {
@@ -406,32 +357,3 @@ biniou_go(const uint32_t nb_frames)
     }
   }
 }
-
-
-void
-biniou_get_delay(const enum RandomDelays what, int *min, int *max)
-{
-  *min = delays[what][0];
-  *max = delays[what][1];
-}
-
-
-void
-biniou_set_delay(const enum RandomDelays what, const int min, const int max)
-{
-  if ((min < 1) || (max < 1)) {
-    xerror("Set random delay for %s: min (%d) and max (%d) must be >= 1\n",
-           delay_names[what], min, max);
-  }
-
-  if (max < min) {
-    xerror("Set random delay for %s: max (%d) must be >= min (%d)\n",
-           delay_names[what], max, min);
-  }
-
-#ifdef DEBUG
-  printf("[i] Setting min..max delays for %s: %d..%d\n", delay_names[what], min, max);
-#endif
-  delays[what][0] = min;
-  delays[what][1] = max;
-}
