@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2020 Olivier Girondel
+ *  Copyright 1994-2021 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -25,6 +25,7 @@
 extern uint8_t max_fps;
 extern uint16_t http_port;
 static pthread_t ping_thread;
+extern uint8_t launch_browser;
 
 
 static void *
@@ -112,6 +113,15 @@ Context_start_ulfius(Context_t *ctx)
   }
 
   xpthread_create(&ping_thread, NULL, ui_thread, (void *)ctx);
+
+  if (launch_browser) {
+    gchar *cmd = g_strdup_printf("/usr/bin/xdg-open http://localhost:%d", http_port);
+    int ret = system(cmd);
+    if (ret == -1) {
+      xperror("system");
+    }
+    g_free(cmd);
+  }
 }
 
 
@@ -119,7 +129,6 @@ void
 Context_stop_ulfius(Context_t *ctx)
 {
   xpthread_join(ping_thread, NULL);
-  xpthread_mutex_destroy(&ctx->ws_clients_mutex);
 
   ulfius_remove_endpoint_by_val(&ctx->instance, BULFIUS_GET, BULFIUS_COLORMAP, NULL);
   ulfius_remove_endpoint_by_val(&ctx->instance, BULFIUS_GET, BULFIUS_COMMANDS, NULL);
@@ -141,4 +150,5 @@ Context_stop_ulfius(Context_t *ctx)
 
   ulfius_stop_framework(&ctx->instance);
   ulfius_clean_instance(&ctx->instance);
+  xpthread_mutex_destroy(&ctx->ws_clients_mutex);
 }
