@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2020 Olivier Girondel
+ *  Copyright 1994-2021 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -231,6 +231,9 @@ callback_websocket(const struct _u_request *request, struct _u_response *respons
              &websocket_manager_callback, user_data,
              &websocket_incoming_message_callback, user_data,
              &websocket_onclose_callback, user_data)) == U_OK) {
+#if ULFIUS_VERSION_NUMBER >= 0x020700
+    ulfius_add_websocket_deflate_extension(response);
+#endif
     return U_CALLBACK_CONTINUE;
   } else {
     return U_CALLBACK_ERROR;
