@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2020 Olivier Girondel
+ *  Copyright 1994-2021 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -35,6 +35,7 @@ extern char    *playlist_filename;
 extern char    *audio_file;
 extern uint8_t  enable_osd;
 extern uint8_t  usage_statistics;
+extern uint8_t  launch_browser;
 
 
 #define MIN_WIDTH  80
@@ -66,6 +67,7 @@ usage()
          "\t-y, --height <height>\tSet height [%d]\n"
 #endif
          "\t-z, --schemes <file>\tSet the schemes file [" DEFAULT_SCHEMES_FILE "]\n"
+         "\t-B, --no-browser\tDon't open the web interface in a browser\n"
 #ifdef WITH_WEBCAM
          "\t-C, --cam-flip <h|v>\tFlip webcam image horizontally/vertically\n"
          "\t-D, --device <device>\tWebcam base [" DEFAULT_VIDEO_DEVICE "]\n"
@@ -110,7 +112,7 @@ getargs(int argc, char **argv)
   int w, h;
 #endif
 
-  static const char *arg_list = "a:b:c:C:d:D:EfF:Ghi:lm:nNo:p:P:qr:sSt:x:X:y:Y:vw:W:z:";
+  static const char *arg_list = "a:b:c:BC:d:D:EfF:Ghi:lm:nNo:p:P:qr:sSt:x:X:y:Y:vw:W:z:";
 
 #if HAVE_GETOPT_LONG
   static struct option long_opt[] = {
@@ -137,6 +139,7 @@ getargs(int argc, char **argv)
     {"height", required_argument, NULL, 'y'},
 #endif
     {"schemes", required_argument, NULL, 'z'},
+    {"no-browser", no_argument, NULL, 'B'},
 #ifdef WITH_WEBCAM
     {"cam-flip", required_argument, NULL, 'C'},
     {"device", required_argument, NULL, 'D'},
@@ -319,6 +322,10 @@ getargs(int argc, char **argv)
         }
         break;
 
+      case 'B':
+        launch_browser = 0;
+        break;
+
 #ifdef WITH_WEBCAM
       case 'C':
         if (*optarg == 'h') {
