@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2020 Olivier Girondel
+ *  Copyright 1994-2021 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -219,7 +219,7 @@ void Context_set_engine_random_mode(Context_t *, const enum RandomMode);
 void Context_insert_plugin(Context_t *, Plugin_t *);
 void Context_remove_plugin(Context_t *, Plugin_t *);
 
-void Context_screenshot(const Context_t *);
+void Context_screenshot(Context_t *);
 float Context_fps(const Context_t *);
 
 void Context_first_sequence(Context_t *);
@@ -338,4 +338,6 @@ void Context_next_track(Context_t *);
 // Video
 void Context_push_video(Context_t *, Buffer8_t *);
 
+void Context_create_timers(Context_t *);
+
 #endif /* __BINIOU_CONTEXT_H */
