@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2020 Olivier Girondel
+ *  Copyright 1994-2021 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -145,6 +145,13 @@ Context_process_ui_command(Context_t *ctx, const enum Command cmd, const json_t
       }
       break;
 
+    case UI_CMD_APP_GET_LAYER_MODES:
+#ifdef DEBUG_COMMANDS
+      printf(">>> UI_CMD_APP_GET_LAYER_MODES\n");
+#endif
+      res = layer_modes();
+      break;
+
     case UI_CMD_APP_GET_SHORTCUTS:
       if (json_is_string(arg)) {
 #ifdef DEBUG_COMMANDS
@@ -363,6 +370,21 @@ Context_process_ui_command(Context_t *ctx, const enum Command cmd, const json_t
     }
     break;
 
+  case UI_CMD_SEQ_SET_LAYER_MODE: {
+    const json_t *j_plugin = json_object_get(arg, "plugin");
+    const json_t *j_mode = json_object_get(arg, "mode");
+
+    if (json_is_string(j_plugin) && json_is_integer(j_mode)) {
+#ifdef DEBUG_COMMANDS
+      printf(">>> CMD_SEQ_SET_LAYER_MODE plugin: %s, mode: %s\n", json_string_value(j_plugin), LayerMode_to_string(json_integer_value(j_mode)));
+#endif
+      SequenceManager_set_layer_mode(ctx->sm->cur, json_string_value(j_plugin), json_integer_value(j_mode));
+      res = json_object();
+      json_object_set_new(res, "sequence", Sequence_to_json(ctx->sm->cur, 1, 0));
+    }
+  }
+  break;
+
     case UI_CMD_SEQ_SET_PARAM_SLIDER_VALUE: {
       json_t *j_param = json_object_get(arg, "selected_param");
       json_t *j_value = json_object_get(arg, "value");
