@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2020 Olivier Girondel
+ *  Copyright 1994-2021 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -42,6 +42,8 @@ extern double volume_scale;
 extern uint8_t start_with_first_sequence;
 extern uint16_t http_port;
 extern uint8_t use_hard_timers;
+extern uint8_t launch_browser;
+extern uint8_t enable_osd;
 
 
 static void process_timers(GKeyFile *);
@@ -73,6 +75,8 @@ process(GKeyFile *kf)
   gchar first_sequence = FALSE;
   gint kf_http_port;
   gchar hard_timers = FALSE;
+  gchar web_ui = TRUE;
+  gchar sdl2_ui = FALSE;
 
   input = g_key_file_get_string(kf, PLUGINS, "Input", NULL);
   if (NULL != input) {
@@ -116,6 +120,36 @@ process(GKeyFile *kf)
     error = NULL;
   }
 
+  web_ui = g_key_file_get_boolean(kf, ENGINE, "WebInterface", &error);
+  if (NULL == error) {
+    launch_browser = web_ui;
+#ifdef DEBUG
+    if (launch_browser) {
+      printf("[k] Launching web browser\n");
+    } else {
+      printf("[k] Not launching web browser\n");
+    }
+#endif
+  } else {
+    g_error_free(error);
+    error = NULL;
+  }
+
+  sdl2_ui = g_key_file_get_boolean(kf, ENGINE, "LegacyInterface", &error);
+  if (NULL == error) {
+    enable_osd = sdl2_ui;
+#ifdef DEBUG
+    if (enable_osd) {
+      printf("[k] Using SDL2 interface\n");
+    } else {
+      printf("[k] Not using SDL2 interface\n");
+    }
+#endif
+  } else {
+    g_error_free(error);
+    error = NULL;
+  }
+
   first_sequence = g_key_file_get_boolean(kf, ENGINE, "StartWithFirstSequence", &error);
   if (NULL == error) {
     start_with_first_sequence = first_sequence;
