@@ -1,6 +1,6 @@
 /*
- *  Copyright 1994-2020 Olivier Girondel
- *  Copyright 2019-2020 Laurent Marsac
+ *  Copyright 1994-2021 Olivier Girondel
+ *  Copyright 2019-2021 Laurent Marsac
  *
  *  This file is part of lebiniou.
  *
@@ -161,11 +161,10 @@ bare_sequence:
     }
 
     json_t *parameters = json_copy(json_object_get(j_p, "parameters"));
-    if (NULL != parameters) {
+    if ((NULL != parameters) && (NULL != p->parameters)) {
 #ifdef DEBUG_SEQUENCE_V0
       DEBUG_JSON("old params", parameters);
 #endif
-      assert(NULL != p->parameters);
       json_t *new_params = p->parameters(NULL, NULL, 1); // fetch all parameters
       assert(NULL != new_params);
 #ifdef DEBUG_SEQUENCE_V0
