@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2020 Olivier Girondel
+ *  Copyright 1994-2021 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -44,11 +44,7 @@ xerror(const char *fmt, ...)
   vfprintf(stderr, fmt, ap);
   va_end(ap);
 
-#ifdef DEBUG
-  assert(0); /* to get a backtrace */
-#else
-  exit(1);
-#endif
+  abort(); /* to get a backtrace */
 }
 
 
@@ -315,9 +311,10 @@ safe_filename(const char *filename)
 }
 
 
+#if 0 // until we're sure issues are fixed
 void
 xpthread_create(pthread_t *thread, const pthread_attr_t *attr,
-                     void *(*start_routine) (void *), void *arg)
+                void *(*start_routine) (void *), void *arg)
 {
   if (pthread_create(thread, attr, start_routine, arg) != 0) {
     xerror("pthread_create failed\n");
@@ -368,3 +365,4 @@ xpthread_mutex_init(pthread_mutex_t *restrict mutex, const pthread_mutexattr_t *
     xerror("xpthread_mutex_init failed\n");
   }
 }
+#endif
