@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2020 Olivier Girondel
+ *  Copyright 1994-2021 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -24,6 +24,8 @@ let prefs = { };
 let preview_fps = 1;
 let update_interval = null;
 let img = null;
+let layer_modes = [];
+let selected_plugin = "";
 
 
 function connect() {
@@ -34,6 +36,7 @@ function connect() {
 
     lb_ws.onopen = function() {
         console.log("Connected");
+        ui_command('UI_CMD_APP_GET_LAYER_MODES', null);
         ui_command('UI_CMD_CONNECT', null);
         ui_command('UI_CMD_APP_GET_SHORTCUTS', 'COL');
         ui_command('UI_CMD_APP_GET_SHORTCUTS', 'IMG');
@@ -122,7 +125,7 @@ function connect() {
 
 
     lb_ws.onerror = function(err) {
-        console.error('Socket encountered error: ', err.message, 'Closing socket');
+        console.error('Socket encountered error: ', err, 'Closing socket');
         lb_ws.close();
     }
 }
@@ -381,6 +384,10 @@ function lebiniou_command_result(r) {
         mute_result(r.result.mute);
         return 1;
 
+    case "UI_CMD_APP_GET_LAYER_MODES":
+        layer_modes = r.result;
+        return 1;
+
     case "UI_CMD_APP_SET_AUTO_MODE":
     case "UI_CMD_APP_GET_SHORTCUTS":
         return 1;
